@@ -42,7 +42,7 @@ FileDetailsDialog::FileDetailsDialog(QWidget *parent, QFileInfo info) :
     ui->ownerInfo->setText(QString("%1:%2").arg(info.owner(), info.group()));
 
     // Modification date
-    ui->modificationInfo->setText(info.lastModified().toString());
+    ui->modificationInfo->setText(FileSystemModel::dateString(info.lastModified()));
 
     // Permissions
     QFile::Permissions permissions = info.permissions();
@@ -66,6 +66,12 @@ FileDetailsDialog::FileDetailsDialog(QWidget *parent, QFileInfo info) :
             box->setEnabled(false);
 
     ui->nameEdit->setFocus();
+
+    // If the name has an extansion, select only the base
+    int dotIndex = ui->nameEdit->text().lastIndexOf(".");
+    if (dotIndex > 0)
+        ui->nameEdit->setSelection(0, dotIndex);
+
     this->adjustSize();
 
     connect(ui->saveButton, SIGNAL(clicked()), this, SLOT(save()));
