@@ -1,6 +1,6 @@
 /**************************************************************************
     Hamster Filer
-    Copyright (C) 2012 Grzegorz Gidel
+    Copyright (C) 2012-2013 Grzegorz Gidel
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,19 +16,19 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
-#include <QtGui/QApplication>
+#include <QApplication>
 
-#include "global.h"
 #include "mainwindow.h"
 
 int main(int argc, char  *argv[])
 {
     QApplication::setOrganizationName("hamsterfiler");
     QApplication::setApplicationName("hamsterfiler");
-    QApplication::setApplicationVersion("0.5");
 
     QApplication app(argc, argv);
 
+    QLocale::setDefault(QLocale("C"));
+
     MainWindow window(argc > 1 ? argv[1] : QString());
 
     if (QString(getenv("USER")) == "root")
