@@ -23,7 +23,7 @@ ShareDialog::ShareDialog(QStringList files, QWidget *parent) :
 void ShareDialog::onBluetoothClicked()
 {
     for (int i = 0; i < files.size(); i++)
-        files[i] = QUrl::toPercentEncoding(QUrl::fromLocalFile(files.at(i)).toString());
+        files[i] = QUrl::fromLocalFile(files.at(i)).toEncoded();
 
     QDBusInterface("com.nokia.icd_ui",
                    "/com/nokia/bt_ui",
@@ -37,7 +37,7 @@ void ShareDialog::onBluetoothClicked()
 void ShareDialog::onEmailClicked()
 {
     for (int i = 0; i < files.size(); i++)
-        files[i] = QUrl::toPercentEncoding(QUrl::fromLocalFile(files.at(i)).toString());
+        files[i] = QUrl::fromLocalFile(files.at(i)).toEncoded();
 
     QDBusInterface("com.nokia.modest",
                    "/com/nokia/modest",
